--- ../fltk-1.1.x-r4283/src/screen_xywh.orig	Thu Apr 21 09:39:53 2005
+++ ../fltk-1.1.x-r4283/src/screen_xywh.cxx	Thu Apr 21 09:46:54 2005
@@ -40,6 +40,13 @@
 #    include <multimon.h>
 #  endif // !HMONITOR_DECLARED && _WIN32_WINNT < 0x0500
 
+// BOOL EnumDisplayMonitors(HDC, LPCRECT, MONITORENUMPROC, LPARAM)
+typedef BOOL (*edm)(HDC, LPCRECT, MONITORENUMPROC, LPARAM);
+// BOOL GetMonitorInfo(HMONITOR, LPMONITORINFO)
+typedef BOOL (*gmi)(HMONITOR, LPMONITORINFO);
+
+static gmi pGMI = NULL; // used to get a proc pointer for GetMonitorInfoA
+
 static RECT screens[16];
 
 static BOOL CALLBACK screen_cb(HMONITOR mon, HDC, LPRECT, LPARAM) {
@@ -48,19 +55,42 @@
   MONITORINFO mi;
   mi.cbSize = sizeof(mi);
 
-  GetMonitorInfo(mon, &mi);
+//  GetMonitorInfo(mon, &mi);
+  if (pGMI) pGMI(mon, &mi);
+
   screens[num_screens] = mi.rcWork;
   num_screens ++;
   return TRUE;
 }
 
 static void screen_init() {
-  num_screens = GetSystemMetrics(SM_CMONITORS);
-  if (num_screens > 1) {
-    // If there is more than 1 monitor, enumerate them...
-    num_screens = 0;
-    EnumDisplayMonitors(0,0,screen_cb,0);
+  HMODULE hMod = GetModuleHandle("USER32.DLL");
+  if (hMod){
+    // check that EnumDisplayMonitors is available
+    FARPROC pAdd = GetProcAddress(hMod, "EnumDisplayMonitors");
+    if (pAdd){
+      // We do have EnumDisplayMonitors, so lets find out how many monitors there are
+      num_screens = GetSystemMetrics(SM_CMONITORS);
+      if (num_screens > 1) {
+        // If there is more than 1 monitor, enumerate them...
+        num_screens = 0; //start with no screens...
+        // keep a pointer to EnumDisplayMonitors
+        edm pEnum = (edm)pAdd;
+        // Now check that we also have GetMonitorInfoA
+        pAdd = GetProcAddress(hMod, "GetMonitorInfoA");
+        if(pAdd){
+          // We have GetMonitorInfoA, store it for use by screen_cb()
+          pGMI = (gmi)pAdd;
+          // Enumerate all the screens
+//        EnumDisplayMonitors(0,0,screen_cb,0);
+          pEnum(0, 0, screen_cb, 0);
+          return;
+        }
+      }
+    }
   }
+  // else fail-safe! Assume we have 1 monitor
+  num_screens = 1;
 }
 #elif defined(__APPLE__)
 XRectangle screens[16];
